@@ -11,13 +11,15 @@ class TestThread(IntegrationHelper):
         self.token_login()
         cassette_name = self.cassette_name("subscription")
         with self.recorder.use_cassette(cassette_name):
-            repository = self.gh.repository('sigmavirus24', 'github3.py')
+            repository = self.gh.repository("sigmavirus24", "github3.py")
             threads = list(repository.notifications(all=True))
             assert len(threads) > 0
             thread = threads[0]
             assert isinstance(thread, github3.notifications.Thread)
-            assert isinstance(thread.subscription(),
-                              github3.notifications.ThreadSubscription)
+            assert isinstance(
+                thread.subscription(),
+                github3.notifications.ThreadSubscription,
+            )
 
 
 class TestThreadSubscription(IntegrationHelper):
@@ -28,10 +30,11 @@ class TestThreadSubscription(IntegrationHelper):
         self.token_login()
         cassette_name = self.cassette_name("set")
         with self.recorder.use_cassette(cassette_name):
-            repository = self.gh.repository('sigmavirus24', 'github3.py')
-            threads = list(repository.notifications(all='true'))
+            repository = self.gh.repository("sigmavirus24", "github3.py")
+            threads = list(repository.notifications(all="true"))
             assert len(threads) > 0
             subscription = threads[0].subscription()
             assert subscription.set(True, False) is None
-            assert isinstance(subscription,
-                              github3.notifications.ThreadSubscription)
+            assert isinstance(
+                subscription, github3.notifications.ThreadSubscription
+            )
