@@ -1390,6 +1390,14 @@ class TestGitHubSearchIterators(helper.UnitSearchIteratorHelper):
             headers={},
         )
 
+    def test_api_version_header(_):
+        gh = GitHub(api_version="2022-11-28")
+        assert gh.session.headers.get("X-GitHub-Api-Version") == "2022-11-28"
+
+    def test_api_version_header_not_defined(_):
+        gh = GitHub()
+        assert gh.session.headers.get("X-GitHub-Api-Version") is None
+
 
 class TestGitHubRequiresAuthentication(
     helper.UnitRequiresAuthenticationHelper
@@ -1579,7 +1587,6 @@ class TestGitHubAuthorizations(helper.UnitHelper):
 
 
 class TestGitHubEnterprise(helper.UnitGitHubEnterpriseHelper):
-
     described_class = GitHubEnterprise
 
     def test_admin_stats(self):
